@@ -1,24 +1,13 @@
 /*
-    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDAV_DAVITEMMODIFYJOB_H
 #define KDAV_DAVITEMMODIFYJOB_H
 
-#include "kpimkdav_export.h"
+#include "kdav_export.h"
 
 #include "davitem.h"
 #include "davjobbase.h"
@@ -30,7 +19,7 @@ class DavItemModifyJobPrivate;
 /**
  * @short A job that modifies a DAV item on the DAV server.
  */
-class KPIMKDAV_EXPORT DavItemModifyJob : public DavJobBase
+class KDAV_EXPORT DavItemModifyJob : public DavJobBase
 {
     Q_OBJECT
 
