@@ -1,19 +1,10 @@
 /*
-    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>
-    Based on DavItemsListJob which is copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Grégory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+    Based on DavItemsListJob:
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "davitemsfetchjob.h"
