@@ -1,18 +1,7 @@
 /*
-    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "davitemslistjob.h"
@@ -256,7 +245,12 @@ void DavItemsListJob::davJobFinished(KJob *job)
         }
     }
 
-    QSet<QString> removed = d->mEtagCache->urls().toSet();
+    const auto etagCacheUrls = d->mEtagCache->urls();
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    QSet<QString> removed = etagCacheUrls.toSet();
+#else
+    QSet<QString> removed(etagCacheUrls.begin(), etagCacheUrls.end());
+#endif
     removed.subtract(d->mSeenUrls);
     d->mDeletedItems = removed.values();
 
